@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import sys
 import json
 import logging
 import os
@@ -29,6 +30,8 @@ from gi.repository import Gio, GLib, Gtk
 
 from lutris import pga
 from lutris.config import check_config
+from lutris.settings import VERSION
+from lutris.util.dxvk import init_dxvk_versions
 from lutris.platforms import update_platforms
 from lutris.gui.dialogs import ErrorDialog, InstallOrPlayDialog
 from lutris.migrations import migrate
@@ -52,6 +55,7 @@ class Application(Gtk.Application):
         gettext.textdomain("lutris")
 
         check_config()
+        init_dxvk_versions()
         migrate()
         update_platforms()
 
@@ -59,6 +63,9 @@ class Application(Gtk.Application):
         self.window = None
         self.css_provider = Gtk.CssProvider.new()
 
+        if os.geteuid() == 0:
+            ErrorDialog("Running Lutris as root is not recommended and may cause unexpected issues")
+
         try:
             self.css_provider.load_from_path(os.path.join(datapath.get(), 'ui', 'lutris.css'))
         except GLib.Error as e:
@@ -79,6 +86,12 @@ class Application(Gtk.Application):
             )
         else:
             logger.warning("This version of Gtk doesn't support set_option_context_summary")
+        self.add_main_option('version',
+                             ord('v'),
+                             GLib.OptionFlags.NONE,
+                             GLib.OptionArg.NONE,
+                             _('Print the version of Lutris and exit'),
+                             None)
         self.add_main_option('debug',
                              ord('d'),
                              GLib.OptionFlags.NONE,
@@ -173,7 +186,7 @@ class Application(Gtk.Application):
                 self.css_provider,
                 Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
             )
-        self.window.present()
+            GLib.timeout_add(300, self.refresh_status)
 
     @staticmethod
     def _print(command_line, string):
@@ -189,6 +202,13 @@ class Application(Gtk.Application):
 
         # Text only commands
 
+        # Print Lutris version and exit
+        if options.contains('version'):
+            executable_name=os.path.basename(sys.argv[0])
+            print(executable_name + "-" + VERSION)
+            logger.setLevel(logging.NOTSET)
+            return 0
+            
         # List game
         if options.contains('list-games'):
             game_list = pga.get_games()
@@ -271,34 +291,36 @@ class Application(Gtk.Application):
                 action = 'install'
 
         if action == 'install':
+            self.window.present()
             self.window.on_install_clicked(game_slug=game_slug,
                                            installer_file=installer_file,
                                            revision=revision)
         elif action in ('rungame', 'rungameid'):
             if not db_game or not db_game['id']:
-                logger.info("No game found in library, shutting down")
-                self.do_shutdown()
+                if self.window.is_visible():
+                    logger.info("No game found in library")
+                else:
+                    logger.info("No game found in library, shutting down")
+                    self.do_shutdown()
                 return 0
 
             logger.info("Launching %s" % db_game['name'])
 
-            # If game is installed, run it without showing the GUI
-            # Also set a timer to shut down lutris when game ends
-            if db_game['installed']:
-                self.window.hide()
-                self.window.on_game_run(game_id=db_game['id'])
-                GLib.timeout_add(300, self.refresh_status)
-            # If game is not installed, show the GUI
-            else:
-                self.window.on_game_run(game_id=db_game['id'])
+            # If game is not installed, show the GUI before running. Otherwise leave the GUI closed.
+            if not db_game['installed']:
+                self.window.present()
+            self.window.on_game_run(game_id=db_game['id'])
 
+        else:
+            self.window.present()
 
         return 0
 
     def refresh_status(self):
-        if self.window.running_game.state == self.window.running_game.STATE_STOPPED:
-            self.do_shutdown()
-            return False
+        if self.window.running_game is None or self.window.running_game.state == self.window.running_game.STATE_STOPPED:
+            if not self.window.is_visible():
+                self.do_shutdown()
+                return False
         return True
 
     def get_lutris_action(self, url):
