@@ -47,23 +47,34 @@ class GameStore(GObject.Object):
         "icons-changed": (GObject.SIGNAL_RUN_FIRST, None, (str,))
     }
 
-    def __init__(self, games, icon_type, filter_installed):
+    def __init__(self, games, icon_type, filter_installed, show_installed_first=False):
         super(GameStore, self).__init__()
         self.games = games
         self.icon_type = icon_type
         self.filter_installed = filter_installed
+        self.show_installed_first = show_installed_first
         self.filter_text = None
         self.filter_runner = None
         self.filter_platform = None
+        self.modelfilter = None
         self.runner_names = {}
 
         self.store = Gtk.ListStore(int, str, str, Pixbuf, str, str, str, str, int, str, bool, int, str)
-        self.store.set_sort_column_id(COL_NAME, Gtk.SortType.ASCENDING)
+        if show_installed_first:
+            self.store.set_sort_column_id(COL_INSTALLED, Gtk.SortType.DESCENDING)
+        else:
+            self.store.set_sort_column_id(COL_NAME, Gtk.SortType.ASCENDING)
         self.modelfilter = self.store.filter_new()
         self.modelfilter.set_visible_func(self.filter_view)
         if games:
             self.fill_store(games)
 
+    def __str__(self):
+        return (
+            "GameStore: <filter_installed: {filter_installed}, "
+            "filter_text: {filter_text}>".format(**self.__dict__)
+        )
+
     def get_ids(self):
         return [row[COL_ID] for row in self.store]
 
@@ -80,12 +91,12 @@ class GameStore(GObject.Object):
 
     def _fill_store_generator(self, games, batch=100):
         """Generator to fill the model in batches."""
-        n = 0
+        loop = 0
         for game in games:
             self.add_game(game)
             # Yield to GTK main loop once in a while
-            n += 1
-            if (n % batch) == 0:
+            loop += 1
+            if (loop % batch) == 0:
                 # Returning True to GLib.idle_add makes it run the callback
                 # again. (Yeah, the GTK doc isn't clear about this feature :)
                 yield True
@@ -111,6 +122,14 @@ class GameStore(GObject.Object):
                 return False
         return True
 
+    def sort_view(self, show_installed_first=False):
+        self.show_installed_first = show_installed_first
+        self.store.set_sort_column_id(COL_NAME, Gtk.SortType.ASCENDING)
+        self.modelfilter.get_model().set_sort_column_id(COL_NAME, Gtk.SortType.ASCENDING)
+        if show_installed_first:
+            self.store.set_sort_column_id(COL_INSTALLED, Gtk.SortType.DESCENDING)
+            self.modelfilter.get_model().set_sort_column_id(COL_INSTALLED, Gtk.SortType.DESCENDING)
+
     def add_game_by_id(self, game_id):
         """Add a game into the store."""
         if not game_id:
@@ -172,6 +191,7 @@ class GameStore(GObject.Object):
             game['installed_at'],
             installed_at_text
         ))
+        self.sort_view(self.show_installed_first)
 
     def set_icon_type(self, icon_type):
         if icon_type != self.icon_type:
