@@ -10,13 +10,16 @@ class LogTextView(Gtk.TextView):
         self.set_editable(False)
         self.set_monospace(True)
         self.set_left_margin(10)
+        self.scroll_max = 0
         self.set_wrap_mode(Gtk.WrapMode.CHAR)
         self.get_style_context().add_class('lutris-logview')
         self.connect("size-allocate", self.autoscroll)
 
     def autoscroll(self, *args):
         adj = self.get_vadjustment()
-        adj.set_value(adj.get_upper() - adj.get_page_size())
+        if adj.get_value() == self.scroll_max or self.scroll_max == 0:
+            adj.set_value(adj.get_upper() - adj.get_page_size())
+        self.scroll_max = adj.get_upper() - adj.get_page_size()
 
 
 class LogWindow(Dialog):
