@@ -1,5 +1,5 @@
 """Main window for the Lutris interface."""
-# pylint: disable=E0611
+# pylint: disable=no-member
 import os
 import math
 import time
@@ -78,8 +78,9 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
         view_type = self.get_view_type()
         self.load_icon_type_from_settings(view_type)
-        self.filter_installed = \
-            settings.read_setting('filter_installed') == 'true'
+        self.filter_installed = settings.read_setting('filter_installed') == 'true'
+        self.show_installed_first = \
+            settings.read_setting('show_installed_first') == 'true'
         self.sidebar_visible = \
             settings.read_setting('sidebar_visible') in ['true', None]
         self.use_dark_theme = settings.read_setting('dark_theme') == 'true'
@@ -89,8 +90,8 @@ class LutrisWindow(Gtk.ApplicationWindow):
             service.sync_with_lutris()
 
         # Window initialization
-        self.game_list = pga.get_games()
-        self.game_store = GameStore([], self.icon_type, self.filter_installed)
+        self.game_list = pga.get_games(show_installed_first=self.show_installed_first)
+        self.game_store = GameStore([], self.icon_type, self.filter_installed, self.show_installed_first)
         self.view = self.get_view(view_type)
         super().__init__(default_width=width,
                          default_height=height,
@@ -188,6 +189,8 @@ class LutrisWindow(Gtk.ApplicationWindow):
             'show-installed-only': Action(self.on_show_installed_state_change, type='b',
                                           default=self.filter_installed,
                                           accel='<Primary>h'),
+            'show-installed-first': Action(self.on_show_installed_first_state_change, type='b',
+                                           default=self.show_installed_first),
             'view-type': Action(self.on_viewtype_state_change, type='s',
                                 default=self.current_view_type),
             'icon-type': Action(self.on_icontype_state_change, type='s',
@@ -254,15 +257,15 @@ class LutrisWindow(Gtk.ApplicationWindow):
                     'name': appmanifest.name,
                     'slug': appmanifest.slug,
                 }
-            game_id = steam.mark_as_installed(appmanifest.steamid,
-                                              runner_name,
-                                              game_info)
-            game_ids = [game['id'] for game in self.game_list]
-            if game_id not in game_ids:
-                self.add_game_to_view(game_id)
-            else:
-                self.view.set_installed(Game(game_id))
-
+            if steam in get_services_synced_at_startup():
+                game_id = steam.mark_as_installed(appmanifest.steamid,
+                                                  runner_name,
+                                                  game_info)
+                game_ids = [game['id'] for game in self.game_list]
+                if game_id not in game_ids:
+                    self.add_game_to_view(game_id)
+                else:
+                    self.view.set_installed(Game(game_id))
     @staticmethod
     def set_dark_theme(is_dark):
         gtksettings = Gtk.Settings.get_default()
@@ -279,6 +282,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
         This must be called each time the view is rebuilt.
         """
+        self.connect('delete-event', lambda *x: self.hide_on_delete())
         self.view.connect('game-installed', self.on_game_installed)
         self.view.connect("game-activated", self.on_game_run)
         self.view.connect("game-selected", self.game_selection_changed)
@@ -317,15 +321,19 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.icon_type = default
         return self.icon_type
 
-    def switch_splash_screen(self):
-        if len(self.game_list) == 0:
-            self.splash_box.show()
-            self.sidebar_paned.hide()
-            self.games_scrollwindow.hide()
-        else:
+    def switch_splash_screen(self, force=None):
+        """Toggle the state of the splash screen based on the library contents"""
+        if not self.splash_box.get_visible() and len(self.game_list):
+            return
+        if len(self.game_list) or force is True:
             self.splash_box.hide()
             self.sidebar_paned.show()
             self.games_scrollwindow.show()
+        else:
+            logger.debug('Showing splash screen')
+            self.splash_box.show()
+            self.sidebar_paned.hide()
+            self.games_scrollwindow.hide()
 
     def switch_view(self, view_type):
         """Switch between grid view and list view."""
@@ -361,8 +369,8 @@ class LutrisWindow(Gtk.ApplicationWindow):
                     for p in range(math.ceil(len(added_ids) / page_size))
                 ])
                 self.game_list += added_games
-                self.view.populate_games(added_games)
                 self.switch_splash_screen()
+                self.view.populate_games(added_games)
                 GLib.idle_add(self.update_existing_games, added_ids, updated_ids, True)
             else:
                 logger.error("No results returned when syncing the library")
@@ -376,10 +384,15 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     def update_existing_games(self, added, updated, first_run=False):
         for game_id in updated.difference(added):
-            # XXX this migth not work if the game has no 'item' set
+            # XXX this might not work if the game has no 'item' set
+            logger.debug("Updating row for ID %s" % game_id)
             self.view.update_row(pga.get_game_by_field(game_id, 'id'))
 
         if first_run:
+            logger.info("Setting up view for first run")
+            for game_id in added:
+                logger.debug("Adding %s", game_id)
+                self.add_game_to_view(game_id)
             icons_sync = AsyncCall(self.sync_icons, callback=None)
             self.threads_stoppers.append(icons_sync.stop_request.set)
             self.set_status("")
@@ -389,9 +402,15 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.threads_stoppers += self.runtime_updater.cancellables
 
     def sync_icons(self):
+        game_slugs = [game['slug'] for game in self.game_list]
+        if not game_slugs:
+            return
+        logger.debug("Syncing %d icons" % len(game_slugs))
         try:
-            resources.fetch_icons([game['slug'] for game in self.game_list],
-                                  callback=self.on_image_downloaded)
+            GLib.idle_add(
+                resources.fetch_icons, game_slugs,
+                self.on_image_downloaded
+            )
         except TypeError as ex:
             logger.exception("Invalid game list:\n%s\nException: %s", self.game_list, ex)
 
@@ -441,7 +460,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
             username = credentials["username"]
         self.toggle_connection(True, username)
         self.sync_library()
-        self.connect_link.hide()
+        self.connect_link.set_sensitive(False)
         self.actions['synchronize'].props.enabled = True
 
     @GtkTemplate.Callback
@@ -496,6 +515,20 @@ class LutrisWindow(Gtk.ApplicationWindow):
         """Callback when preferences is activated."""
         SystemConfigDialog(parent=self)
 
+    def on_show_installed_first_state_change(self, action, value):
+        action.set_state(value)
+        show_installed_first = value.get_boolean()
+        self.set_show_installed_first_state(show_installed_first)
+
+    def set_show_installed_first_state(self, show_installed_first):
+        self.show_installed_first = show_installed_first
+        setting_value = 'true' if show_installed_first else 'false'
+        settings.write_setting(
+            'show_installed_first', setting_value
+        )
+        self.game_store.sort_view(show_installed_first)
+        self.game_store.modelfilter.refilter()
+
     def on_show_installed_state_change(self, action, value):
         action.set_state(value)
         filter_installed = value.get_boolean()
@@ -658,7 +691,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
         def do_add_game():
             self.view.add_game_by_id(game_id)
-            self.switch_splash_screen()
+            self.switch_splash_screen(force=True)
             self.sidebar_treeview.update()
             return False
 
