@@ -14,9 +14,13 @@ from lutris.util.strings import version_sort, parse_version
 from lutris.util.wineprefix import WinePrefixManager
 from lutris.util.x360ce import X360ce
 from lutris.util import dxvk
+from lutris.util import vulkan
+from lutris.util.vulkan import vulkan_available
 from lutris.runners.runner import Runner
 from lutris.thread import LutrisThread
 from lutris.gui.dialogs import FileDialog
+from lutris.gui.dialogs import ErrorDialog
+from lutris.gui.dialogs import DontShowAgainDialog
 
 WINE_DIR = os.path.join(settings.RUNNER_DIR, "wine")
 MIN_SAFE_VERSION = '3.0'  # Wine installers must run with at least this version
@@ -64,6 +68,7 @@ def get_overrides_env(overrides):
         ('b,n', []),
         ('b', []),
         ('n', []),
+        ('d', []),
         ('', [])
     ])
     for dll, value in overrides.items():
@@ -436,6 +441,13 @@ def get_wine_version_exe(version):
 def is_version_installed(version):
     return os.path.isfile(get_wine_version_exe(version))
 
+def is_esync_limit_set():
+    nolimit = subprocess.Popen("ulimit -Hn", shell=True, stdout=subprocess.PIPE).stdout.read()
+    nolimit = int(nolimit)
+    if nolimit < 1048576:
+        return False
+    else:
+        return True
 
 def get_default_version():
     """Return the default version of wine. Prioritize 64bit builds"""
@@ -474,6 +486,14 @@ def support_legacy_version(version):
         version += '-i386'
     return version
 
+def is_version_esync(version, path):
+    command = path + " --version"
+    wine_ver = str(subprocess.Popen(command, shell=True, stdout=subprocess.PIPE).stdout.read())
+    if wine_ver.lower().find('esync') != -1:
+        return True
+    if version.lower().find('esync') != -1:
+        return True
+    return False
 
 def get_real_executable(windows_executable, working_dir=None):
     """Given a Windows executable, return the real program
@@ -495,6 +515,52 @@ def get_real_executable(windows_executable, working_dir=None):
 
     return (windows_executable, [], working_dir)
 
+def display_vulkan_error(option, on_launch):
+    if option == vulkan_available.NONE:
+        message = "No Vulkan loader was detected."
+    if option == vulkan_available.SIXTY_FOUR:
+        message = "32-bit Vulkan loader was not detected."
+    if option == vulkan_available.THIRTY_TWO:
+        message = "64-bit Vulkan loader was not detected."
+
+    if on_launch:
+        checkbox_message = "Launch anyway and do not show this message again."
+    else:
+        checkbox_message = "Enable anyway and do not show this message again."
+
+    setting = 'hide-no-vulkan-warning'
+    DontShowAgainDialog(setting,
+                        message,
+                        secondary_message="Please follow the installation "
+                        "procedures as described in\n"
+                        "<a href='https://github.com/lutris/lutris/wiki/How-to:-DXVK'>"
+                        "How-to:-DXVK (https://github.com/lutris/lutris/wiki/How-to:-DXVK)</a>",
+                        checkbox_message=checkbox_message)
+    if settings.read_setting(setting) == 'True':
+        return True
+    return False
+
+def esync_display_limit_warning():
+    ErrorDialog("Your limits are not set correctly."
+                " Please increase them as described here:"
+                " <a href='https://github.com/lutris/lutris/wiki/How-to:-Esync'>"
+                "How-to:-Esync (https://github.com/lutris/lutris/wiki/How-to:-Esync)</a>")
+
+def esync_display_version_warning(on_launch):
+    setting = 'hide-wine-non-esync-version-warning'
+    if on_launch:
+        checkbox_message= "Launch anyway and do not show this message again."
+    else:
+        checkbox_message= "Enable anyway and do not show this message again."
+
+    DontShowAgainDialog(setting,
+                        "Incompatible Wine version detected",
+                        secondary_message="The wine build you have selected does not seem to support Esync.\n"
+                        "Please switch to an esync-capable version.",
+                        checkbox_message=checkbox_message)
+    if settings.read_setting(setting) == 'True':#
+        return True
+    return False
 
 # pylint: disable=C0103
 class wine(Runner):
@@ -553,10 +619,10 @@ class wine(Runner):
         "MouseWarpOverride": r"%s/DirectInput" % reg_prefix,
         "OffscreenRenderingMode": r"%s/Direct3D" % reg_prefix,
         "StrictDrawOrdering": r"%s/Direct3D" % reg_prefix,
-        "Desktop": r"%s/Explorer" % reg_prefix,
-        "WineDesktop": r"%s/Explorer/Desktops" % reg_prefix,
-        "ShowCrashDialog": r"%s/WineDbg" % reg_prefix,
-        "UseXVidMode": r"%s/X11 Driver" % reg_prefix
+        "Desktop": "MANAGED",
+        "WineDesktop": "MANAGED",
+        "ShowCrashDialog": "MANAGED",
+        "UseXVidMode": "MANAGED"
     }
 
     core_processes = (
@@ -609,6 +675,29 @@ class wine(Runner):
                 version_choices.append((version, version))
             return version_choices
 
+        def esync_limit_callback(config):
+            limits_set = is_esync_limit_set()
+            wine_path = self.get_path_for_version(config['version'])
+            wine_ver = is_version_esync(config['version'], wine_path)
+            if not limits_set and not wine_ver:
+                esync_display_version_warning(False)
+                esync_display_limit_warning()
+                return False
+            elif not limits_set:
+                esync_display_limit_warning()
+                return False
+            elif not wine_ver:
+                if not esync_display_version_warning(False):
+                    return False
+            return True
+
+        def dxvk_vulkan_callback(config):
+            result = vulkan.vulkan_check()
+            if result != vulkan_available.ALL:
+                if not display_vulkan_error(result, False):
+                    return False
+            return True
+
         self.runner_options = [
             {
                 'option': 'version',
@@ -630,8 +719,11 @@ class wine(Runner):
             {
                 'option': 'dxvk',
                 'label': 'Enable DXVK',
-                'type': 'bool',
-                'help': 'Use DXVK to translate DirectX 11 calls to Vulkan'
+                'type': 'extended_bool',
+                'help': 'Use DXVK to translate DirectX 11 calls to Vulkan',
+                'callback': dxvk_vulkan_callback,
+                'callback_on': True,
+                'active': True
             },
             {
                 'option': 'dxvk_version',
@@ -640,6 +732,15 @@ class wine(Runner):
                 'choices': get_dxvk_choices,
                 'default': dxvk.DXVK_LATEST
             },
+            {
+                'option': 'esync',
+                'label': 'Enable Esync',
+                'type': 'extended_bool',
+                'help': 'Enable eventfd-based synchronization (esync)',
+                'callback': esync_limit_callback,
+                'callback_on': True,
+                'active': True
+            },
             {
                 'option': 'x360ce-path',
                 'label': "Path to the game's executable, for x360ce support",
@@ -978,26 +1079,17 @@ class wine(Runner):
         self.prelaunch()
         joycpl(prefix=self.prefix_path, wine_path=self.get_executable(), config=self)
 
-    def set_wine_desktop(self, enable_desktop=False):
-        prefix = self.prefix_path
-        prefix_manager = WinePrefixManager(prefix)
-        path = self.reg_keys['Desktop']
-
-        if enable_desktop:
-            prefix_manager.set_registry_key(path, 'Desktop', 'WineDesktop')
-        else:
-            prefix_manager.clear_registry_key(path)
-
     def set_regedit_keys(self):
         """Reset regedit keys according to config."""
         prefix = self.prefix_path
-        enable_wine_desktop = False
         prefix_manager = WinePrefixManager(prefix)
         # Those options are directly changed with the prefix manager and skip
         # any calls to regedit.
         managed_keys = {
             'ShowCrashDialog': prefix_manager.set_crash_dialogs,
-            'UseXVidMode': prefix_manager.use_xvid_mode
+            'UseXVidMode': prefix_manager.use_xvid_mode,
+            'Desktop': prefix_manager.set_virtual_desktop,
+            'WineDesktop': prefix_manager.set_desktop_size
         }
 
         for key, path in self.reg_keys.items():
@@ -1005,10 +1097,7 @@ class wine(Runner):
             if not value or value == 'auto' and key not in managed_keys.keys():
                 prefix_manager.clear_registry_key(path)
             elif key in self.runner_config:
-                if key == 'Desktop' and value is True:
-                    enable_wine_desktop = True
-                    continue
-                elif key in managed_keys.keys():
+                if key in managed_keys.keys():
                     # Do not pass fallback 'auto' value to managed keys
                     if value == 'auto':
                         value = None
@@ -1016,8 +1105,6 @@ class wine(Runner):
                     continue
                 prefix_manager.set_registry_key(path, key, value)
 
-        self.set_wine_desktop(enable_wine_desktop)
-
     def toggle_dxvk(self, enable, version=None):
         dxvk_manager = dxvk.DXVKManager(self.prefix_path, arch=self.wine_arch, version=version)
 
@@ -1068,6 +1155,9 @@ class wine(Runner):
         if self.prefix_path:
             env['WINEPREFIX'] = self.prefix_path
 
+        if not ("WINEESYNC" in env and env["WINEESYNC"] == "1"):
+            env["WINEESYNC"] = "1" if self.runner_config.get('esync') else "0"
+
         overrides = self.get_dll_overrides()
         if overrides:
             env['WINEDLLOVERRIDES'] = get_overrides_env(overrides)
@@ -1149,6 +1239,13 @@ class wine(Runner):
     def play(self):
         game_exe = self.game_exe
         arguments = self.game_config.get('args', '')
+        using_dxvk = self.runner_config.get('dxvk')
+
+        if using_dxvk:
+            result = vulkan.vulkan_check()
+            if result != vulkan_available.ALL:
+                if not display_vulkan_error(result, True):
+                    return {'error': 'VULKAN_NOT_FOUND'}
 
         if not os.path.exists(game_exe):
             return {'error': 'FILE_NOT_FOUND', 'file': game_exe}
@@ -1156,6 +1253,22 @@ class wine(Runner):
         launch_info = {}
         launch_info['env'] = self.get_env(os_env=False)
 
+        if 'WINEESYNC' in launch_info['env']:
+            if launch_info['env']['WINEESYNC'] == "1":
+                limit_set = is_esync_limit_set()
+                wine_ver = is_version_esync(self.runner_config['version'], self.get_executable())
+
+                if not limit_set and not wine_ver:
+                    esync_display_version_warning(True)
+                    esync_display_limit_warning()
+                    return {'error': 'ESYNC_LIMIT_NOT_SET'}
+                elif not is_esync_limit_set():
+                    esync_display_limit_warning()
+                    return {'error': 'ESYNC_LIMIT_NOT_SET'}
+                elif not wine_ver:
+                    if not esync_display_version_warning(True):
+                        return {'error': 'NON_ESYNC_WINE_VERSION'}
+
         command = [self.get_executable()]
 
         game_exe, _args, working_dir = get_real_executable(game_exe, self.working_dir)
