@@ -46,7 +46,7 @@ INSTALLED_TERMINALS = []
 IS_64BIT = sys.maxsize > 2**32
 
 
-def execute(command, env=None, cwd=None, log_errors=False, quiet=False):
+def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=False):
     """
         Execute a system command and return its results.
 
@@ -91,7 +91,7 @@ def execute(command, env=None, cwd=None, log_errors=False, quiet=False):
     try:
         stdout, stderr = subprocess.Popen(
             command,
-            shell=False,
+            shell=shell,
             stdout=subprocess.PIPE,
             stderr=stderr_handler,
             env=existing_env, cwd=cwd
@@ -354,10 +354,12 @@ def reverse_expanduser(path):
 
 
 def path_exists(path):
-    """Wrapper around os.path.exists that doesn't crash with empty values"""
+    """Wrapper around os.path.exists that doesn't crash with empty values
+    Also return True for broken symlinks.
+    """
     if not path:
         return False
-    return os.path.exists(path)
+    return os.path.exists(path) or os.path.islink(path)
 
 
 def path_is_empty(path):
